<?php
/*
Plugin Name: Scroll To Top Button Awesome
Plugin URI: http://w3layoutsdesign.com/about/
Description: Awesome scroll to top wordpress plugin.
Version: 3.1
Author: thebestdesigns
Author URI: http://w3layoutsdesigns.com
License: A "Slug" license name e.g. GPL2
Text Domain: scrollToTopButtonAwesome
*/

// check if the class not exist
if ( ! class_exists( 'ScrollToTopPlugin' ) ) {

	// class
	class ScrollToTopPlugin {

		// constructor
		public function __construct() {
			add_action( 'admin_enqueue_scripts', array( $this, 'remove_redux_framework_notice' ) );
			add_action( 'wp_footer', array( $this, 'front_view_scroll_bar' ) );
			add_action( 'wp_enqueue_scripts', array( $this, 'front_view_style_register' ) );
			add_action( 'wp_enqueue_scripts', array( $this, 'front_view_script_register' ) );
			add_action( 'wp_print_styles', array( $this, 'google_fonts_load' ) );
		}

		// redux frame integrated
		public function redux_frame_integrated() {
			// check if the admin
			if ( is_admin() ) {
				// redux framework intigrated for plugin options create
				require_once 'admin-init.php';
			}
		}

		// remove redux framework notice bar
		public function remove_redux_framework_notice() {
			// admin css
			wp_register_style( 'redux_header_notice_remove', plugins_url( 'css/scrollToTopAdmin.css', __FILE__ ) );
			wp_enqueue_style( 'redux_header_notice_remove' );

			// admin js
			wp_enqueue_script( 'scroll_to_top-admin-script', plugins_url( 'js/scrollToTop_admin.js', __FILE__ ),
				array( 'jquery' ), false, true );
		}

		// front view css register
		public function front_view_style_register() {
			wp_register_style( 'front-stylesheet-scrollToTop', plugins_url( 'css/scrollToTop.css', __FILE__ ) );
			wp_enqueue_style( 'front-stylesheet-scrollToTop' );

			// import inline-style.php file
			require_once 'inline-style.php';

			// get value from database
			$get_from_database = get_option( 'scrollToTop_Options' );

			// load the font awesome css icons file when button label type option is icon
			if ( $get_from_database['button-label-type'] === 'font-icons' ) {
				// font icons css
				wp_register_style( 'front-stylesheet-scrollToTop-font-icons', plugins_url( 'css/font-icons.css', __FILE__ ) );
				wp_enqueue_style( 'front-stylesheet-scrollToTop-font-icons' );
			}
		}

		// front view script register
		public function front_view_script_register() {
			wp_register_script( 'front-script-scrollToTop', plugins_url( 'js/scrollToTop.min.js', __FILE__ ),
				array( 'jquery' ), false, true );
			// get value from database
			$get_from_database = get_option( 'scrollToTop_Options' );
			// inline js options
			$custom_js = array(
				'scroll_duration'     => $get_from_database['scroll-bar-scroll-duration'], // 400
				'visibility_duration' => $get_from_database['scroll-bar-visibility-duration'], // 0
				'easing_animation'    => $get_from_database['animation_easing'] // easing
			);
			// end
			wp_localize_script( 'front-script-scrollToTop', 'scrollToTopScript_Options', $custom_js );
			wp_enqueue_script( 'front-script-scrollToTop' );
		}

		// google fonts load
		public function google_fonts_load() {
			// get value from database
			$get_from_database = get_option( 'scrollToTop_Options' );

			if ( isset( $get_from_database['button-label-typography-google-font'] ) ) {
				wp_register_style( 'scrollToTop-googleFonts', $get_from_database['button-label-typography-google-font'] );
			}
			wp_enqueue_style( 'scrollToTop-googleFonts' );
		}

		// add scroll bar on front of the screen
		public function front_view_scroll_bar() {
			// get value from database
			$get_from_database = get_option( 'scrollToTop_Options' );

			if ( $get_from_database['visibility-radio-button'] === 'enable' ) {

				// add hover.css class on color type
				if ( $get_from_database['color-type-change'] === 'color' ) {
					// effects works on color option
					$hover_css_class = $get_from_database['scroll-bar-hover-animations'];

					// add hover.css class on gradient type
				} elseif ( $get_from_database['color-type-change'] === 'gradient' ) {
					// effects works on color option
					$hover_css_class = $get_from_database['scroll-bar-hover-animations-gradient'];

					// add hover.css class on image type
				} elseif ( $get_from_database['color-type-change'] === 'image' ) {
					// effects works on color option
					$hover_css_class = $get_from_database['scroll-bar-hover-animations-image'];

				} else {
					$hover_css_class = false;
				}

				?>
				<div class="scrollToTopPlugin">
					<div class="scrollToTopPluginInner <?php echo $hover_css_class; ?>">
						<?php
						// hide the label
						if ( $get_from_database['button-label-type-hide'] === '1' ) {
							?>
							<span class="scrollToTopPlugin_label">
                            <!-- font awesome icons -->
								<?php
								// button label type icons. If this option is icons. Show the icons only
								if ( $get_from_database['button-label-type'] === 'font-icons' ) {
									// switch case
									switch ( $get_from_database['button-label-icons'] ) {
										// case
										case '1': ?> <i class="fa fa-arrow-circle-o-up icon_1"></i> <?php break;
										case '2': ?> <i class="fa fa-play-circle-o icon_2"></i> <?php break;
										case '3': ?> <i class="fa fa-tint icon_3"></i> <?php break;
										case '4': ?> <i class="fa fa-play icon_4"></i> <?php break;
										case '5': ?> <i class="fa fa-eject icon_5"></i> <?php break;
										case '6': ?> <i class="fa fa-arrow-up icon_6"></i> <?php break;
										case '7': ?> <i class="fa fa-fire icon_7"></i> <?php break;
										case '8': ?> <i class="fa fa-plane icon_8"></i> <?php break;
										case '9': ?> <i class="fa fa-random icon_9"></i> <?php break;
										case '10': ?> <i class="fa fa-chevron-up icon_10"></i> <?php break;
										case '11': ?> <i class="fa fa-arrows-v icon_11"></i> <?php break;
										case '12': ?> <i class="fa fa-sign-out icon_12"></i> <?php break;
										case '13': ?> <i class="fa fa-upload icon_13"></i> <?php break;
										case '14': ?> <i class="fa fa-hand-o-up icon_14"></i> <?php break;
										case '15': ?> <i class="fa fa-arrow-circle-up icon_15"></i> <?php break;
										case '16': ?> <i class="fa fa-sort-up icon_16"></i> <?php break;
										case '17': ?> <i class="fa fa-umbrella icon_17"></i> <?php break;
										case '18': ?> <i class="fa fa-cloud-upload icon_18"></i> <?php break;
										case '19': ?> <i class="fa fa-angle-double-up icon_19"></i> <?php break;
										case '20': ?> <i class="fa fa-angle-up icon_20"></i> <?php break;
										case '21': ?> <i class="fa fa-location-arrow icon_21"></i> <?php break;
										case '22': ?> <i class="fa fa-shield icon_22"></i> <?php break;
										case '23': ?> <i class="fa fa-rocket icon_23"></i> <?php break;
										case '24': ?> <i class="fa fa-chevron-circle-up icon_24"></i> <?php break;
										case '25': ?> <i class="fa fa-ellipsis-v icon_25"></i> <?php break;
										case '26': ?> <i class="fa fa-play-circle icon_26"></i> <?php break;
										case '27': ?> <i class="fa fa-level-up icon_27"></i> <?php break;
										case '28': ?> <i class="fa fa-caret-square-o-up icon_28"></i> <?php break;
										case '29': ?> <i class="fa fa-long-arrow-up icon_29"></i> <?php break;
										case '30': ?> <i class="fa fa-arrow-circle-o-up icon_30"></i> <?php break;
										case '31': ?> <i class="fa fa-yahoo icon_31"></i> <?php break;
										case '32': ?> <i class="fa fa-spoon icon_32"></i> <?php break;
										case '33': ?> <i class="fa fa-tree icon_33"></i> <?php break;
										case '34': ?> <i class="fa fa-vine icon_34"></i> <?php break;
										case '35': ?> <i class="fa fa-share-alt icon_35"></i> <?php break;
										case '36': ?> <i class="fa fa-eyedropper icon_36"></i> <?php break;
										case '37': ?> <i class="fa fa-forumbee icon_37"></i> <?php break;
										case '38': ?> <i class="fa fa-venus icon_38"></i> <?php break;
										case '39': ?> <i class="fa fa-mars icon_39"></i> <?php break;
										case '40': ?> <i class="fa fa-mars-stroke-v icon_40"></i> <?php break;
										case '41': ?> <i class="fa fa-neuter icon_41"></i> <?php break;
										case '42': ?> <i class="fa fa-hand-pointer-o icon_42"></i> <?php break;
										case '43': ?> <i class="fa fa-map-marker icon_43"></i> <?php break;
										case '44': ?> <span class="fa-span icon-1"></span> <?php break;
										case '45': ?> <span class="fa-span icon-2"></span> <?php break;
										case '46': ?> <span class="fa-span icon-3"></span> <?php break;
										case '47': ?> <span class="fa-span icon-4"></span> <?php break;
										case '48': ?> <span class="fa-span icon-5"></span> <?php break;
										case '49': ?> <span class="fa-span icon-6"></span> <?php break;
										case '50': ?> <span class="fa-span icon-7"></span> <?php break;
										case '51': ?> <span class="fa-span icon-8"></span> <?php break;
										case '52': ?> <span class="fa-span icon-10"></span> <?php break;
										case '53': ?> <span class="fa-span icon-11"></span> <?php break;
										case '54': ?> <span class="fa-span icon-13"></span> <?php break;
										case '55': ?> <span class="fa-span icon-14"></span> <?php break;
										case '56': ?> <span class="fa-span icon-15"></span> <?php break;
										case '57': ?> <span class="fa-span icon-16"></span> <?php break;
										case '58': ?> <span class="fa-span icon-17"></span> <?php break;
										case '59': ?> <span class="fa-span icon-18"></span> <?php break;
										case '60': ?> <span class="fa-span icon-19"></span> <?php break;
										case '61': ?> <span class="fa-span icon-20"></span> <?php break;
										case '62': ?> <span class="fa-span icon-21"></span> <?php break;
										case '63': ?> <span class="fa-span icon-22"></span> <?php break;
										case '64': ?> <span class="fa-span icon-23"></span> <?php break;
										case '65': ?> <span class="fa-span icon-24"></span> <?php break;
										case '66': ?> <span class="fa-span icon-25"></span> <?php break;
										case '67': ?> <span class="fa-span icon-26"></span> <?php break;
										case '68': ?> <span class="fa-span icon-27"></span> <?php break;
										case '69': ?> <span class="fa-span icon-28"></span> <?php break;
										case '70': ?> <span class="fa-span icon-29"></span> <?php break;
										case '71': ?> <span class="fa-span icon-30"></span> <?php break;
										case '72': ?> <span class="fa-span icon-31"></span> <?php break;
										case '73': ?> <span class="fa-span icon-32"></span> <?php break;
										case '74': ?> <span class="fa-span icon-33"></span> <?php break;
										case '75': ?> <span class="fa-span icon-34"></span> <?php break;
										case '76': ?> <span class="fa-span icon-35"></span> <?php break;
										case '77': ?> <span class="fa-span icon-36"></span> <?php break;
										case '78': ?> <span class="fa-span icon-37"></span> <?php break;
										case '79': ?> <span class="fa-span icon-38"></span> <?php break;
										case '80': ?> <span class="fa-span icon-39"></span> <?php break;
										case '81': ?> <span class="fa-span icon-40"></span> <?php break;
										case '82': ?> <span class="fa-span icon-41"></span> <?php break;
										case '83': ?> <span class="fa-span icon-42"></span> <?php break;
										case '84': ?> <span class="fa-span icon-43"></span> <?php break;
										case '85': ?> <span class="fa-span icon-44"></span> <?php break;
										case '86': ?> <span class="fa-span icon-45"></span> <?php break;
										case '87': ?> <span class="fa-span icon-46"></span> <?php break;
										case '88': ?> <span class="fa-span icon-47"></span> <?php break;
										case '89': ?> <span class="fa-span icon-48"></span> <?php break;
										case '90': ?> <span class="fa-span icon-49"></span> <?php break;
										case '91': ?> <span class="fa-span icon-50"></span> <?php break;
										case '92': ?> <span class="fa-span icon-51"></span> <?php break;
										case '93': ?> <span class="fa-span icon-52"></span> <?php break;
										case '94': ?> <span class="fa-span icon-53"></span> <?php break;
										case '95': ?> <span class="fa-span icon-54"></span> <?php break;
										case '96': ?> <span class="fa-span icon-55"></span> <?php break;
										case '97': ?> <span class="fa-span icon-56"></span> <?php break;
										case '98': ?> <span class="fa-span icon-57"></span> <?php break;
										case '99': ?> <span class="fa-span icon-58"></span> <?php break;
										case '100': ?> <span class="fa-span icon-59"></span> <?php break;
										case '101': ?> <span class="fa-span icon-60"></span> <?php break;
										case '102': ?> <span class="fa-span icon-61"></span> <?php break;
										case '103': ?> <span class="fa-span icon-62"></span> <?php break;
										case '104': ?> <span class="fa-span icon-63"></span> <?php break;
										case '105': ?> <span class="fa-span icon-64"></span> <?php break;
										case '106': ?> <span class="fa-span icon-65"></span> <?php break;
										case '107': ?> <span class="fa-span icon-66"></span> <?php break;
										case '108': ?> <span class="fa-span icon-67"></span> <?php break;
										case '109': ?> <span class="fa-span icon-68"></span> <?php break;
										case '110': ?> <span class="fa-span icon-69"></span> <?php break;
										case '111': ?> <span class="fa-span icon-70"></span> <?php break;
										case '112': ?> <span class="fa-span icon-71"></span> <?php break;
										case '113': ?> <span class="fa-span icon-72"></span> <?php break;
										case '114': ?> <span class="fa-span icon-73"></span> <?php break;
										case '115': ?> <span class="fa-span icon-74"></span> <?php break;
										case '116': ?> <span class="fa-span icon-75"></span> <?php break;
										case '117': ?> <span class="fa-span icon-76"></span> <?php break;
										case '118': ?> <span class="fa-span icon-77"></span> <?php break;
										case '119': ?> <span class="fa-span icon-78"></span> <?php break;
										case '120': ?> <span class="fa-span icon-79"></span> <?php break;
										case '121': ?> <span class="fa-span icon-80"></span> <?php break;
										case '122': ?> <span class="fa-span icon-90"></span> <?php break;
										case '123': ?> <span class="fa-span icon-100"></span> <?php break;
										case '124': ?> <span class="fa-span icon-101"></span> <?php break;
										case '125': ?> <span class="fa-span icon-102"></span> <?php break;
										case '126': ?> <span class="fa-span icon-103"></span> <?php break;
										case '127': ?> <span class="fa-span icon-104"></span> <?php break;
										case '128': ?> <span class="fa-span icon-105"></span> <?php break;
										case '129': ?> <span class="fa-span icon-106"></span> <?php break;
										case '130': ?> <span class="fa-span icon-107"></span> <?php break;
										case '131': ?> <span class="fa-span icon-108"></span> <?php break;
										case '132': ?> <span class="fa-span icon-109"></span> <?php break;
										case '133': ?> <span class="fa-span icon-110"></span> <?php break;
										case '134': ?> <span class="fa-span icon-111"></span> <?php break;
										case '135': ?> <span class="fa-span icon-112"></span> <?php break;
										case '136': ?> <span class="fa-span icon-113"></span> <?php break;
										case '137': ?> <span class="fa-span icon-114"></span> <?php break;
										case '138': ?> <span class="fa-span icon-115"></span> <?php break;
										case '139': ?> <span class="fa-span icon-116"></span> <?php break;
										case '140': ?> <span class="fa-span icon-117"></span> <?php break;
										case '141': ?> <span class="fa-span icon-118"></span> <?php break;
										case '142': ?> <span class="fa-span icon-119"></span> <?php break;
										case '143': ?> <span class="fa-span icon-120"></span> <?php break;
										case '144': ?> <span class="fa-span icon-121"></span> <?php break;
										case '145': ?> <span class="fa-span icon-122"></span> <?php break;
										case '146': ?> <span class="fa-span icon-123"></span> <?php break;
										case '147': ?> <span class="fa-span icon-124"></span> <?php break;
										case '148': ?> <span class="fa-span icon-125"></span> <?php break;
										case '149': ?> <span class="fa-span icon-126"></span> <?php break;
										case '150': ?> <span class="fa-span icon-127"></span> <?php break;
										case '151': ?> <span class="fa-span icon-128"></span> <?php break;
										case '152': ?> <span class="fa-span icon-129"></span> <?php break;
										case '153': ?> <span class="fa-span icon-130"></span> <?php break;
										case '154': ?> <span class="fa-span icon-131"></span> <?php break;
										case '155': ?> <span class="fa-span icon-132"></span> <?php break;
										case '156': ?> <span class="fa-span icon-133"></span> <?php break;
										case '157': ?> <span class="fa-span icon-134"></span> <?php break;
										case '158': ?> <span class="fa-span icon-135"></span> <?php break;
										case '159': ?> <span class="fa-span icon-136"></span> <?php break;
										case '160': ?> <span class="fa-span icon-137"></span> <?php break;
										case '161': ?> <span class="fa-span icon-138"></span> <?php break;
										case '162': ?> <span class="fa-span icon-139"></span> <?php break;
										case '163': ?> <span class="fa-span icon-140"></span> <?php break;
										case '164': ?> <span class="fa-span icon-141"></span> <?php break;
										case '165': ?> <span class="fa-span icon-142"></span> <?php break;
										case '166': ?> <span class="fa-span icon-143"></span> <?php break;
										case '167': ?> <span class="fa-span icon-144"></span> <?php break;
										case '168': ?> <span class="fa-span icon-145"></span> <?php break;
										case '169': ?> <span class="fa-span icon-146"></span> <?php break;
										case '170': ?> <span class="fa-span icon-147"></span> <?php break;
										case '171': ?> <span class="fa-span icon-148"></span> <?php break;
										case '172': ?> <span class="fa-span icon-149"></span> <?php break;
										case '173': ?> <span class="fa-span icon-150"></span> <?php break;
										case '174': ?> <span class="fa-span icon-151"></span> <?php break;
										case '175': ?> <span class="fa-span icon-152"></span> <?php break;
										case '176': ?> <span class="fa-span icon-153"></span> <?php break;
										case '177': ?> <span class="fa-span icon-154"></span> <?php break;
										case '178': ?> <span class="fa-span icon-155"></span> <?php break;
										case '179': ?> <span class="fa-span icon-156"></span> <?php break;
										case '180': ?> <span class="fa-span icon-157"></span> <?php break;
										case '181': ?> <span class="fa-span icon-158"></span> <?php break;
										case '182': ?> <span class="fa-span icon-159"></span> <?php break;
										case '183': ?> <span class="fa-span icon-160"></span> <?php break;
										case '184': ?> <span class="fa-span icon-161"></span> <?php break;
										case '185': ?> <span class="fa-span icon-162"></span> <?php break;
										case '186': ?> <span class="fa-span icon-163"></span> <?php break;
										case '187': ?> <span class="fa-span icon-164"></span> <?php break;
										case '188': ?> <span class="fa-span icon-165"></span> <?php break;
										case '189': ?> <span class="fa-span icon-166"></span> <?php break;
										case '190': ?> <span class="fa-span icon-167"></span> <?php break;
										case '191': ?> <span class="fa-span icon-168"></span> <?php break;
										case '192': ?> <span class="fa-span icon-169"></span> <?php break;
									}

									// button label type text. If this option is text. Show the text only
								} else if ( $get_from_database['button-label-type'] === 'text' ) {
									// custom label text
									echo $get_from_database['button-label-text'];
								}
								?>
                        </span>
							<?php
						}
						?>

					</div>
				</div>
				<?php
			}

		}
	}

	// call object
	$object = new ScrollToTopPlugin();
	// call functions
	$object->redux_frame_integrated();
}
